SuperFormTranslation class
- Available extensions
Constructors
Properties
- april → String
-
Aprilno setter - atLeastOneFileRequired → String
-
At least one file is requiredno setter - august → String
-
Augustno setter - browse → String
-
Browseno setter - browseOrDragFilesHere → String
-
Browse or drag files hereno setter - cannotBeNegative → String
-
Cannot be negativeno setter - clear → String
-
Clearno setter - close → String
-
Closeno setter - december → String
-
Decemberno setter - decrement → String
-
Decrementno setter - demoFillExamples → String
-
Fill examplesno setter - demoFormCompletionAndSavedValuesSubtitle → String
-
Completion and FormState.save() valuesno setter - demoFormResultTitle → String
-
Form resultno setter - demoFormSavedValuesSubtitle → String
-
Values received through FormState.save()no setter - demoNotSaved → String
-
Not savedno setter - demoNotSavedYet → String
-
Not saved yetno setter - demoReset → String
-
Resetno setter - demoValidateAndSave → String
-
Validate & saveno setter - disabled → String
-
Disabledno setter - dragFilesHere → String
-
or drag files hereno setter - enabled → String
-
Enabledno setter - february → String
-
Februaryno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hide → String
-
Hideno setter - increment → String
-
Incrementno setter - invalidFormat → String
-
Invalid formatno setter - january → String
-
Januaryno setter - july → String
-
Julyno setter - june → String
-
Juneno setter - march → String
-
Marchno setter - may → String
-
Mayno setter -
monthNames
→ List<
String> -
Available on SuperFormTranslation, provided by the SuperFormTranslationCalendarX extension
no setter - mustBeEnabled → String
-
This must be enabled to continueno setter -
narrowWeekdays
→ List<
String> -
Available on SuperFormTranslation, provided by the SuperFormTranslationCalendarX extension
no setter - noMatches → String
-
No matchesno setter - november → String
-
Novemberno setter - october → String
-
Octoberno setter - openCalendar → String
-
Open calendarno setter - otpBackupCodeHelper → String
-
Letters are normalized to uppercase.no setter - otpBackupCodeLabel → String
-
Backup codeno setter - otpBackupCodeResultLabel → String
-
Backup codeno setter - otpBackupSubtitle → String
-
Custom keyboard and formatter compositionno setter - otpBackupTitle → String
-
Alphanumeric backup codeno setter - otpCodesSavedSuccessfully → String
-
Verification codes saved successfully.no setter - otpDemoCardSubtitle → String
-
SMS autofill · paste · secure PIN · completionno setter - otpDemoCardTitle → String
-
Super OTP Fieldno setter - otpDemoEyebrow → String
-
OTP Field • Verification Codesno setter - otpDemoTitle → String
-
OTP Field Examplesno setter - otpLastCompletedLabel → String
-
Last completedno setter - otpPinResultLabel → String
-
PINno setter - otpPinSubtitle → String
-
Four digits displayed with an obscuring characterno setter - otpPinTitle → String
-
Secure transaction PINno setter - otpSmsCodeLabel → String
-
SMS codeno setter - otpSmsSubtitle → String
-
Paste and one-time-code autofill with completionno setter - otpSmsTitle → String
-
SMS verification codeno setter - otpTransactionPinHelper → String
-
The actual digits remain available to save.no setter - otpTransactionPinLabel → String
-
Transaction PINno setter - otpVerificationCodeHelper → String
-
A six-digit code was sent to your phone.no setter - otpVerificationCodeHint → String
-
Enter the code sent by SMSno setter - otpVerificationCodeLabel → String
-
Verification codeno setter - phoneCountryRulesSubtitle → String
-
Compose the phone type with a prefix, mask, and patternno setter - phoneCountryRulesTitle → String
-
Country-specific rulesno setter - phoneDemoCardSubtitle → String
-
International · country rules · formatters · Form saveno setter - phoneDemoCardTitle → String
-
Phone Text Fieldno setter - phoneDemoEyebrow → String
-
Text Field • Phone Inputno setter - phoneDemoTitle → String
-
Phone Field Examplesno setter - phoneInternationalHelper → String
-
Accepts digits, spaces, parentheses, +, and hyphens.no setter - phoneInternationalHint → String
-
e.g. +1 (415) 555-0132no setter - phoneInternationalResultLabel → String
-
Internationalno setter - phoneInternationalSubtitle → String
-
Phone keyboard with common international charactersno setter - phoneInternationalTitle → String
-
International numberno setter - phoneNumberLabel → String
-
Phone numberno setter - phoneNumbersSavedSuccessfully → String
-
Phone numbers saved successfully.no setter - phoneYemenMobileHelper → String
-
Valid prefixes: 70, 71, 73, 77, or 78.no setter - phoneYemenMobileHint → String
-
7X XXX XXXXno setter - phoneYemenMobileInvalid → String
-
Enter a valid Yemeni mobile number.no setter - phoneYemenMobileLabel → String
-
Yemen mobile numberno setter - phoneYemenResultLabel → String
-
Yemenno setter - pickDateFromCalendar → String
-
Pick a date from the calendarno setter - requiredMessage → String
-
This field is requiredno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → String
-
Search...no setter - selectAtLeastOneOption → String
-
Select at least one optionno setter - selectDate → String
-
Select dateno setter - selectOption → String
-
Select an optionno setter - selectPlaceholder → String
-
Select...no setter - september → String
-
Septemberno setter - show → String
-
Showno setter - today → String
-
Todayno setter - validDate → String
-
Enter a valid dateno setter - validEmail → String
-
Enter a valid email addressno setter - weekdayFridayNarrow → String
-
Frno setter - weekdayMondayNarrow → String
-
Mono setter - weekdaySaturdayNarrow → String
-
Sano setter - weekdaySundayNarrow → String
-
Suno setter - weekdayThursdayNarrow → String
-
Thno setter - weekdayTuesdayNarrow → String
-
Tuno setter - weekdayWednesdayNarrow → String
-
Weno setter
Methods
-
attachAtMostFiles(
num count) → String -
{count, plural, =1{Attach at most 1 file} other{Attach at most {count} files}} -
fileCount(
num count) → String -
{count, plural, =1{1 file} other{{count} files}} -
fileNotAccepted(
String name) → String -
"{name}" is not an accepted type -
fileTooLarge(
String name, double size) → String -
"{name}" exceeds {size} MB -
maxCharacters(
num count) → String -
Must be at most {count} characters -
maxDate(
String value) → String -
Must be on or before {value} -
maxFiles(
num count) → String -
max {count} -
maxNumber(
String value) → String -
Must be at most {value} -
minCharacters(
num count) → String -
Must be at least {count} characters -
minDate(
String value) → String -
Must be on or after {value} -
minNumber(
String value) → String -
Must be at least {value} -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
otpLength(
num count) → String -
Enter the complete {count}-character code -
removeFile(
String name) → String -
Remove {name} -
selectAtLeastOptions(
num count) → String -
Select at least {count} options -
selectAtMostOptions(
num count) → String -
Select at most {count} options -
selectedCount(
num count) → String -
{count} selected -
toString(
) → String -
A string representation of this object.
inherited
-
upToMegabytes(
double size) → String -
up to {size} MB
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- current → SuperFormTranslation
-
no setter
Static Methods
-
load(
Locale locale) → Future< SuperFormTranslation> -
maybeOf(
BuildContext context) → SuperFormTranslation? -
of(
BuildContext context) → SuperFormTranslation
Constants
- delegate → const AppLocalizationDelegate